Stan Math Library: stan/math/prim/scal/meta/length_mvt.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
length_mvt.hpp File Reference
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan

## Functions
template<typename T >
size_t | stan::length_mvt (const T &)

[ Stan Home Page ] © 2011–2016, Stan Development Team.